@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -132,8 +132,8 @@ private:
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    FLAC__StreamDecoder* m_decoder;    ///< FLAC decoder
-    ClientData           m_clientData; ///< Structure passed to the decoder callbacks
+    FLAC__StreamDecoder* m_decoder;    //!< FLAC decoder
+    ClientData           m_clientData; //!< Structure passed to the decoder callbacks
 };
 
 } // namespace priv
