@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -101,9 +101,9 @@ private:
     ////////////////////////////////////////////////////////////
     // Member data
     ////////////////////////////////////////////////////////////
-    FLAC__StreamEncoder* m_encoder;      ///< FLAC stream encoder
-    unsigned int         m_channelCount; ///< Number of channels
-    std::vector<Int32>   m_samples32;    ///< Conversion buffer
+    FLAC__StreamEncoder* m_encoder;      //!< FLAC stream encoder
+    unsigned int         m_channelCount; //!< Number of channels
+    std::vector<Int32>   m_samples32;    //!< Conversion buffer
 };
 
 } // namespace priv
