@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -40,6 +40,7 @@
 #include FT_STROKER_H
 #include <cstdlib>
 #include <cstring>
+#include <cmath>
 
 
 namespace
@@ -47,11 +48,12 @@ namespace
     // FreeType callbacks that operate on a sf::InputStream
     unsigned long read(FT_Stream rec, unsigned long offset, unsigned char* buffer, unsigned long count)
     {
+        sf::Int64 convertedOffset = static_cast<sf::Int64>(offset);
         sf::InputStream* stream = static_cast<sf::InputStream*>(rec->descriptor.pointer);
-        if (static_cast<unsigned long>(stream->seek(offset)) == offset)
+        if (stream->seek(convertedOffset) == convertedOffset)
         {
             if (count > 0)
-                return static_cast<unsigned long>(stream->read(reinterpret_cast<char*>(buffer), count));
+                return static_cast<unsigned long>(stream->read(reinterpret_cast<char*>(buffer), static_cast<sf::Int64>(count)));
             else
                 return 0;
         }
@@ -71,10 +73,10 @@ namespace
         return output;
     }
 
-    // Combine outline thickness, boldness and codepoint into a single 64-bit key
-    sf::Uint64 combine(float outlineThickness, bool bold, sf::Uint32 codePoint)
+    // Combine outline thickness, boldness and font glyph index into a single 64-bit key
+    sf::Uint64 combine(float outlineThickness, bool bold, sf::Uint32 index)
     {
-        return (static_cast<sf::Uint64>(reinterpret<sf::Uint32>(outlineThickness)) << 32) | (static_cast<sf::Uint64>(bold) << 31) | codePoint;
+        return (static_cast<sf::Uint64>(reinterpret<sf::Uint32>(outlineThickness)) << 32) | (static_cast<sf::Uint64>(bold) << 31) | index;
     }
 }
 
@@ -88,6 +90,7 @@ m_face     (NULL),
 m_streamRec(NULL),
 m_stroker  (NULL),
 m_refCount (NULL),
+m_isSmooth (true),
 m_info     ()
 {
     #ifdef SFML_SYSTEM_ANDROID
@@ -103,6 +106,7 @@ m_face       (copy.m_face),
 m_streamRec  (copy.m_streamRec),
 m_stroker    (copy.m_stroker),
 m_refCount   (copy.m_refCount),
+m_isSmooth   (copy.m_isSmooth),
 m_info       (copy.m_info),
 m_pages      (copy.m_pages),
 m_pixelBuffer(copy.m_pixelBuffer)
@@ -127,7 +131,7 @@ Font::~Font()
     #ifdef SFML_SYSTEM_ANDROID
 
     if (m_stream)
-        delete (priv::ResourceStream*)m_stream;
+        delete static_cast<priv::ResourceStream*>(m_stream);
 
     #endif
 }
@@ -191,10 +195,10 @@ bool Font::loadFromFile(const std::string& filename)
     #else
 
     if (m_stream)
-        delete (priv::ResourceStream*)m_stream;
+        delete static_cast<priv::ResourceStream*>(m_stream);
 
     m_stream = new priv::ResourceStream(filename);
-    return loadFromStream(*(priv::ResourceStream*)m_stream);
+    return loadFromStream(*static_cast<priv::ResourceStream*>(m_stream));
 
     #endif
 }
@@ -344,10 +348,10 @@ const Font::Info& Font::getInfo() const
 const Glyph& Font::getGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, float outlineThickness) const
 {
     // Get the page corresponding to the character size
-    GlyphTable& glyphs = m_pages[characterSize].glyphs;
+    GlyphTable& glyphs = loadPage(characterSize).glyphs;
 
-    // Build the key by combining the code point, bold flag, and outline thickness
-    Uint64 key = combine(outlineThickness, bold, codePoint);
+    // Build the key by combining the glyph index (based on code point), bold flag, and outline thickness
+    Uint64 key = combine(outlineThickness, bold, FT_Get_Char_Index(static_cast<FT_Face>(m_face), codePoint));
 
     // Search the glyph into the cache
     GlyphTable::const_iterator it = glyphs.find(key);
@@ -366,7 +370,14 @@ const Glyph& Font::getGlyph(Uint32 codePoint, unsigned int characterSize, bool b
 
 
 ////////////////////////////////////////////////////////////
-float Font::getKerning(Uint32 first, Uint32 second, unsigned int characterSize) const
+bool Font::hasGlyph(Uint32 codePoint) const
+{
+    return FT_Get_Char_Index(static_cast<FT_Face>(m_face), codePoint) != 0;
+}
+
+
+////////////////////////////////////////////////////////////
+float Font::getKerning(Uint32 first, Uint32 second, unsigned int characterSize, bool bold) const
 {
     // Special case where first or second is 0 (null character)
     if (first == 0 || second == 0)
@@ -374,26 +385,33 @@ float Font::getKerning(Uint32 first, Uint32 second, unsigned int characterSize)
 
     FT_Face face = static_cast<FT_Face>(m_face);
 
-    if (face && FT_HAS_KERNING(face) && setCurrentSize(characterSize))
+    if (face && setCurrentSize(characterSize))
     {
         // Convert the characters to indices
         FT_UInt index1 = FT_Get_Char_Index(face, first);
         FT_UInt index2 = FT_Get_Char_Index(face, second);
 
-        // Get the kerning vector
+        // Retrieve position compensation deltas generated by FT_LOAD_FORCE_AUTOHINT flag
+        float firstRsbDelta = static_cast<float>(getGlyph(first, characterSize, bold).rsbDelta);
+        float secondLsbDelta = static_cast<float>(getGlyph(second, characterSize, bold).lsbDelta);
+
+        // Get the kerning vector if present
         FT_Vector kerning;
-        FT_Get_Kerning(face, index1, index2, FT_KERNING_DEFAULT, &kerning);
+        kerning.x = kerning.y = 0;
+        if (FT_HAS_KERNING(face))
+            FT_Get_Kerning(face, index1, index2, FT_KERNING_UNFITTED, &kerning);
 
         // X advance is already in pixels for bitmap fonts
         if (!FT_IS_SCALABLE(face))
             return static_cast<float>(kerning.x);
 
-        // Return the X advance
-        return static_cast<float>(kerning.x) / static_cast<float>(1 << 6);
+        // Combine kerning with compensation deltas and return the X advance
+        // Flooring is required as we use FT_KERNING_UNFITTED flag which is not quantized in 64 based grid
+        return std::floor((secondLsbDelta - firstRsbDelta + static_cast<float>(kerning.x) + 32) / static_cast<float>(1 << 6));
     }
     else
     {
-        // Invalid font, or no kerning
+        // Invalid font
         return 0.f;
     }
 }
@@ -424,7 +442,7 @@ float Font::getUnderlinePosition(unsigned int characterSize) const
     {
         // Return a fixed position if font is a bitmap font
         if (!FT_IS_SCALABLE(face))
-            return characterSize / 10.f;
+            return static_cast<float>(characterSize) / 10.f;
 
         return -static_cast<float>(FT_MulFix(face->underline_position, face->size->metrics.y_scale)) / static_cast<float>(1 << 6);
     }
@@ -444,7 +462,7 @@ float Font::getUnderlineThickness(unsigned int characterSize) const
     {
         // Return a fixed thickness if font is a bitmap font
         if (!FT_IS_SCALABLE(face))
-            return characterSize / 14.f;
+            return static_cast<float>(characterSize) / 14.f;
 
         return static_cast<float>(FT_MulFix(face->underline_thickness, face->size->metrics.y_scale)) / static_cast<float>(1 << 6);
     }
@@ -458,7 +476,27 @@ float Font::getUnderlineThickness(unsigned int characterSize) const
 ////////////////////////////////////////////////////////////
 const Texture& Font::getTexture(unsigned int characterSize) const
 {
-    return m_pages[characterSize].texture;
+    return loadPage(characterSize).texture;
+}
+
+////////////////////////////////////////////////////////////
+void Font::setSmooth(bool smooth)
+{
+    if (smooth != m_isSmooth)
+    {
+        m_isSmooth = smooth;
+
+        for (sf::Font::PageTable::iterator page = m_pages.begin(); page != m_pages.end(); ++page)
+        {
+            page->second.texture.setSmooth(m_isSmooth);
+        }
+    }
+}
+
+////////////////////////////////////////////////////////////
+bool Font::isSmooth() const
+{
+    return m_isSmooth;
 }
 
 
@@ -472,6 +510,7 @@ Font& Font::operator =(const Font& right)
     std::swap(m_streamRec,   temp.m_streamRec);
     std::swap(m_stroker,     temp.m_stroker);
     std::swap(m_refCount,    temp.m_refCount);
+    std::swap(m_isSmooth,    temp.m_isSmooth);
     std::swap(m_info,        temp.m_info);
     std::swap(m_pages,       temp.m_pages);
     std::swap(m_pixelBuffer, temp.m_pixelBuffer);
@@ -528,6 +567,18 @@ void Font::cleanup()
 }
 
 
+////////////////////////////////////////////////////////////
+Font::Page& Font::loadPage(unsigned int characterSize) const
+{
+    // TODO: Remove this method and use try_emplace instead when updating to C++17
+    PageTable::iterator pageIterator = m_pages.find(characterSize);
+    if (pageIterator == m_pages.end())
+        pageIterator = m_pages.insert(std::make_pair(characterSize, Page(m_isSmooth))).first;
+
+    return pageIterator->second;
+}
+
+
 ////////////////////////////////////////////////////////////
 Glyph Font::loadGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, float outlineThickness) const
 {
@@ -562,7 +613,7 @@ Glyph Font::loadGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, f
     {
         if (bold)
         {
-            FT_OutlineGlyph outlineGlyph = (FT_OutlineGlyph)glyphDesc;
+            FT_OutlineGlyph outlineGlyph = reinterpret_cast<FT_OutlineGlyph>(glyphDesc);
             FT_Outline_Embolden(&outlineGlyph->outline, weight);
         }
 
@@ -576,8 +627,11 @@ Glyph Font::loadGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, f
     }
 
     // Convert the glyph to a bitmap (i.e. rasterize it)
+    // Warning! After this line, do not read any data from glyphDesc directly, use
+    // bitmapGlyph.root to access the FT_Glyph data.
     FT_Glyph_To_Bitmap(&glyphDesc, FT_RENDER_MODE_NORMAL, 0, 1);
-    FT_Bitmap& bitmap = reinterpret_cast<FT_BitmapGlyph>(glyphDesc)->bitmap;
+    FT_BitmapGlyph bitmapGlyph = reinterpret_cast<FT_BitmapGlyph>(glyphDesc);
+    FT_Bitmap& bitmap = bitmapGlyph->bitmap;
 
     // Apply bold if necessary -- fallback technique using bitmap (lower quality)
     if (!outline)
@@ -590,40 +644,43 @@ Glyph Font::loadGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, f
     }
 
     // Compute the glyph's advance offset
-    glyph.advance = static_cast<float>(face->glyph->metrics.horiAdvance) / static_cast<float>(1 << 6);
+    glyph.advance = static_cast<float>(bitmapGlyph->root.advance.x >> 16);
     if (bold)
         glyph.advance += static_cast<float>(weight) / static_cast<float>(1 << 6);
 
-    int width  = bitmap.width;
-    int height = bitmap.rows;
+    glyph.lsbDelta = static_cast<int>(face->glyph->lsb_delta);
+    glyph.rsbDelta = static_cast<int>(face->glyph->rsb_delta);
+
+    unsigned int width  = bitmap.width;
+    unsigned int height = bitmap.rows;
 
     if ((width > 0) && (height > 0))
     {
         // Leave a small padding around characters, so that filtering doesn't
         // pollute them with pixels from neighbors
-        const unsigned int padding = 1;
+        const unsigned int padding = 2;
 
         width += 2 * padding;
         height += 2 * padding;
 
         // Get the glyphs page corresponding to the character size
-        Page& page = m_pages[characterSize];
+        Page& page = loadPage(characterSize);
 
         // Find a good position for the new glyph into the texture
         glyph.textureRect = findGlyphRect(page, width, height);
 
         // Make sure the texture data is positioned in the center
         // of the allocated texture rectangle
-        glyph.textureRect.left += padding;
-        glyph.textureRect.top += padding;
-        glyph.textureRect.width -= 2 * padding;
-        glyph.textureRect.height -= 2 * padding;
+        glyph.textureRect.left   += static_cast<int>(padding);
+        glyph.textureRect.top    += static_cast<int>(padding);
+        glyph.textureRect.width  -= static_cast<int>(2 * padding);
+        glyph.textureRect.height -= static_cast<int>(2 * padding);
 
         // Compute the glyph's bounding box
-        glyph.bounds.left   =  static_cast<float>(face->glyph->metrics.horiBearingX) / static_cast<float>(1 << 6);
-        glyph.bounds.top    = -static_cast<float>(face->glyph->metrics.horiBearingY) / static_cast<float>(1 << 6);
-        glyph.bounds.width  =  static_cast<float>(face->glyph->metrics.width)        / static_cast<float>(1 << 6) + outlineThickness * 2;
-        glyph.bounds.height =  static_cast<float>(face->glyph->metrics.height)       / static_cast<float>(1 << 6) + outlineThickness * 2;
+        glyph.bounds.left   = static_cast<float>( bitmapGlyph->left);
+        glyph.bounds.top    = static_cast<float>(-bitmapGlyph->top);
+        glyph.bounds.width  = static_cast<float>( bitmap.width);
+        glyph.bounds.height = static_cast<float>( bitmap.rows);
 
         // Resize the pixel buffer to the new size and fill it with transparent white pixels
         m_pixelBuffer.resize(width * height * 4);
@@ -671,10 +728,10 @@ Glyph Font::loadGlyph(Uint32 codePoint, unsigned int characterSize, bool bold, f
         }
 
         // Write the pixels to the texture
-        unsigned int x = glyph.textureRect.left - padding;
-        unsigned int y = glyph.textureRect.top - padding;
-        unsigned int w = glyph.textureRect.width + 2 * padding;
-        unsigned int h = glyph.textureRect.height + 2 * padding;
+        unsigned int x = static_cast<unsigned int>(glyph.textureRect.left) - padding;
+        unsigned int y = static_cast<unsigned int>(glyph.textureRect.top) - padding;
+        unsigned int w = static_cast<unsigned int>(glyph.textureRect.width) + 2 * padding;
+        unsigned int h = static_cast<unsigned int>(glyph.textureRect.height) + 2 * padding;
         page.texture.update(&m_pixelBuffer[0], w, h, x, y);
     }
 
@@ -694,7 +751,7 @@ IntRect Font::findGlyphRect(Page& page, unsigned int width, unsigned int height)
     float bestRatio = 0;
     for (std::vector<Row>::iterator it = page.rows.begin(); it != page.rows.end() && !row; ++it)
     {
-        float ratio = static_cast<float>(height) / it->height;
+        float ratio = static_cast<float>(height) / static_cast<float>(it->height);
 
         // Ignore rows that are either too small or too high
         if ((ratio < 0.7f) || (ratio > 1.f))
@@ -716,7 +773,7 @@ IntRect Font::findGlyphRect(Page& page, unsigned int width, unsigned int height)
     // If we didn't find a matching row, create a new one (10% taller than the glyph)
     if (!row)
     {
-        int rowHeight = height + height / 10;
+        unsigned int rowHeight = height + height / 10;
         while ((page.nextRow + rowHeight >= page.texture.getSize().y) || (width >= page.texture.getSize().x))
         {
             // Not enough space: resize the texture if possible
@@ -727,6 +784,7 @@ IntRect Font::findGlyphRect(Page& page, unsigned int width, unsigned int height)
                 // Make the texture 2 times bigger
                 Texture newTexture;
                 newTexture.create(textureWidth * 2, textureHeight * 2);
+                newTexture.setSmooth(m_isSmooth);
                 newTexture.update(page.texture);
                 page.texture.swap(newTexture);
             }
@@ -745,7 +803,7 @@ IntRect Font::findGlyphRect(Page& page, unsigned int width, unsigned int height)
     }
 
     // Find the glyph's rectangle on the selected row
-    IntRect rect(row->width, row->top, width, height);
+    IntRect rect(Rect<unsigned int>(row->width, row->top, width, height));
 
     // Update the row informations
     row->width += width;
@@ -776,22 +834,27 @@ bool Font::setCurrentSize(unsigned int characterSize) const
                 err() << "Failed to set bitmap font size to " << characterSize << std::endl;
                 err() << "Available sizes are: ";
                 for (int i = 0; i < face->num_fixed_sizes; ++i)
-                    err() << face->available_sizes[i].height << " ";
+                {
+                    const long size = (face->available_sizes[i].y_ppem + 32) >> 6;
+                    err() << size << " ";
+                }
                 err() << std::endl;
             }
+            else
+            {
+                err() << "Failed to set font size to " << characterSize << std::endl;
+            }
         }
 
         return result == FT_Err_Ok;
     }
-    else
-    {
-        return true;
-    }
+
+     return true;
 }
 
 
 ////////////////////////////////////////////////////////////
-Font::Page::Page() :
+Font::Page::Page(bool smooth) :
 nextRow(3)
 {
     // Make sure that the texture is initialized by default
@@ -799,13 +862,13 @@ nextRow(3)
     image.create(128, 128, Color(255, 255, 255, 0));
 
     // Reserve a 2x2 white square for texturing underlines
-    for (int x = 0; x < 2; ++x)
-        for (int y = 0; y < 2; ++y)
+    for (unsigned int x = 0; x < 2; ++x)
+        for (unsigned int y = 0; y < 2; ++y)
             image.setPixel(x, y, Color(255, 255, 255, 255));
 
     // Create the texture
     texture.loadFromImage(image);
-    texture.setSmooth(true);
+    texture.setSmooth(smooth);
 }
 
 } // namespace sf
