@@ -26,6 +26,7 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/System/Unix/ThreadImpl.hpp>
+#include <SFML/System/Err.hpp>
 #include <SFML/System/Thread.hpp>
 #include <iostream>
 #include <cassert>
@@ -42,7 +43,7 @@ m_isActive(true)
     m_isActive = pthread_create(&m_thread, NULL, &ThreadImpl::entryPoint, owner) == 0;
 
     if (!m_isActive)
-        std::cerr << "Failed to create thread" << std::endl;
+        err() << "Failed to create thread" << std::endl;
 }
 
 
