@@ -102,7 +102,8 @@ WindowHandle WindowImplAndroid::getSystemHandle() const
 void WindowImplAndroid::processEvents()
 {
     // Process incoming OS events
-    ALooper_pollAll(0, NULL, NULL, NULL);
+    while (ALooper_pollOnce(0, NULL, NULL, NULL) >= 0)
+        ;
 
     ActivityStates& states = getActivity();
     Lock lock(states.mutex);
