@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -31,7 +31,7 @@
 #include <SFML/System/Mutex.hpp>
 #include <SFML/System/Lock.hpp>
 #include <SFML/System/Err.hpp>
-#include <SFML/OpenGL.hpp>
+#include <glad/gl.h>
 #include <algorithm>
 #include <vector>
 #include <string>
@@ -42,48 +42,74 @@
 #include <cctype>
 #include <cassert>
 
-#if !defined(SFML_OPENGL_ES)
 
-    #if defined(SFML_SYSTEM_WINDOWS)
+#if defined(SFML_SYSTEM_WINDOWS)
 
-        #include <SFML/Window/Win32/WglContext.hpp>
-        typedef sf::priv::WglContext ContextType;
-
-    #elif defined(SFML_SYSTEM_LINUX) || defined(SFML_SYSTEM_FREEBSD) || defined(SFML_SYSTEM_OPENBSD)
-
-        #include <SFML/Window/Unix/GlxContext.hpp>
-        typedef sf::priv::GlxContext ContextType;
-
-    #elif defined(SFML_SYSTEM_MACOS)
-
-        #include <SFML/Window/OSX/SFContext.hpp>
-        typedef sf::priv::SFContext ContextType;
-
-    #endif
-
-#else
-
-    #if defined(SFML_SYSTEM_IOS)
-
-        #include <SFML/Window/iOS/EaglContext.hpp>
-        typedef sf::priv::EaglContext ContextType;
-
-    #else
+    #if defined(SFML_OPENGL_ES)
 
         #include <SFML/Window/EglContext.hpp>
         typedef sf::priv::EglContext ContextType;
 
+    #else
+
+        #include <SFML/Window/Win32/WglContext.hpp>
+        typedef sf::priv::WglContext ContextType;
+
     #endif
 
+#elif defined(SFML_SYSTEM_LINUX) || defined(SFML_SYSTEM_FREEBSD) || defined(SFML_SYSTEM_OPENBSD) || defined(SFML_SYSTEM_NETBSD)
+
+    #if defined(SFML_USE_DRM)
+
+        #include <SFML/Window/DRM/DRMContext.hpp>
+        typedef sf::priv::DRMContext ContextType;
+
+    #elif defined(SFML_OPENGL_ES)
+
+        #include <SFML/Window/EglContext.hpp>
+        typedef sf::priv::EglContext ContextType;
+
+    #else
+
+        #include <SFML/Window/Unix/GlxContext.hpp>
+        typedef sf::priv::GlxContext ContextType;
+
+    #endif
+
+#elif defined(SFML_SYSTEM_MACOS)
+
+    #include <SFML/Window/OSX/SFContext.hpp>
+    typedef sf::priv::SFContext ContextType;
+
+#elif defined(SFML_SYSTEM_IOS)
+
+    #include <SFML/Window/iOS/EaglContext.hpp>
+    typedef sf::priv::EaglContext ContextType;
+
+#elif defined(SFML_SYSTEM_ANDROID)
+
+    #include <SFML/Window/EglContext.hpp>
+    typedef sf::priv::EglContext ContextType;
+
 #endif
 
 #if defined(SFML_SYSTEM_WINDOWS)
 
+    typedef void (APIENTRY *glEnableFuncType)(GLenum);
+    typedef GLenum (APIENTRY *glGetErrorFuncType)();
+    typedef void (APIENTRY *glGetIntegervFuncType)(GLenum, GLint*);
+    typedef const GLubyte* (APIENTRY *glGetStringFuncType)(GLenum);
     typedef const GLubyte* (APIENTRY *glGetStringiFuncType)(GLenum, GLuint);
+    typedef GLboolean (APIENTRY *glIsEnabledFuncType)(GLenum);
 
 #else
 
+    typedef void (*glEnableFuncType)(GLenum);
+    typedef GLenum (*glGetErrorFuncType)();
+    typedef void (*glGetIntegervFuncType)(GLenum, GLint*);
+    typedef const GLubyte* (*glGetStringFuncType)(GLenum);
     typedef const GLubyte* (*glGetStringiFuncType)(GLenum, GLuint);
+    typedef GLboolean (*glIsEnabledFuncType)(GLenum);
 
 #endif
 
@@ -130,106 +156,162 @@
 
 namespace
 {
-    // AMD drivers have issues with internal synchronization
-    // We need to make sure that no operating system context
-    // or pixel format operations are performed simultaneously
-    // This mutex is also used to protect the shared context
-    // from being locked on multiple threads and for managing
-    // the resource count
-    sf::Mutex mutex;
-
-    // OpenGL resources counter
-    unsigned int resourceCount = 0;
-
-    // This per-thread variable holds the current context for each thread
-    sf::ThreadLocalPtr<sf::priv::GlContext> currentContext(NULL);
-
-    // The hidden, inactive context that will be shared with all other contexts
-    ContextType* sharedContext = NULL;
-
-    // Unique identifier, used for identifying contexts when managing unshareable OpenGL resources
-    sf::Uint64 id = 1; // start at 1, zero is "no context"
-
-    // Set containing callback functions to be called whenever a
-    // context is going to be destroyed
-    // Unshareable OpenGL resources rely on this to clean up properly
-    // whenever a context containing them is destroyed
-    typedef std::set<std::pair<sf::ContextDestroyCallback, void*> > ContextDestroyCallbacks;
-    ContextDestroyCallbacks contextDestroyCallbacks;
-
-    // This structure contains all the state necessary to
-    // track TransientContext usage
-    struct TransientContext : private sf::NonCopyable
+    // A nested named namespace is used here to allow unity builds of SFML.
+    namespace GlContextImpl
     {
-        ////////////////////////////////////////////////////////////
-        /// \brief Constructor
-        ///
-        ////////////////////////////////////////////////////////////
-        TransientContext() :
-        referenceCount   (0),
-        context          (0),
-        sharedContextLock(0),
-        useSharedContext (false)
+        // AMD drivers have issues with internal synchronization
+        // We need to make sure that no operating system context
+        // or pixel format operations are performed simultaneously
+        // This mutex is also used to protect the shared context
+        // from being locked on multiple threads and for managing
+        // the resource count
+        sf::Mutex mutex;
+
+        // OpenGL resources counter
+        unsigned int resourceCount = 0;
+
+        // This per-thread variable holds the current context for each thread
+        sf::ThreadLocalPtr<sf::priv::GlContext> currentContext(NULL);
+
+        // The hidden, inactive context that will be shared with all other contexts
+        ContextType* sharedContext = NULL;
+
+        // Unique identifier, used for identifying contexts when managing unshareable OpenGL resources
+        sf::Uint64 id = 1; // start at 1, zero is "no context"
+
+        // Set containing callback functions to be called whenever a
+        // context is going to be destroyed
+        // Unshareable OpenGL resources rely on this to clean up properly
+        // whenever a context containing them is destroyed
+        typedef std::set<std::pair<sf::ContextDestroyCallback, void*> > ContextDestroyCallbacks;
+        ContextDestroyCallbacks contextDestroyCallbacks;
+
+        // This structure contains all the state necessary to
+        // track TransientContext usage
+        struct TransientContext : private sf::NonCopyable
         {
-            if (resourceCount == 0)
+            ////////////////////////////////////////////////////////////
+            /// \brief Constructor
+            ///
+            ////////////////////////////////////////////////////////////
+            TransientContext() :
+            referenceCount   (0),
+            context          (0),
+            sharedContextLock(0),
+            useSharedContext (false)
             {
-                context = new sf::Context;
+                if (resourceCount == 0)
+                {
+                    context = new sf::Context;
+                }
+                else if (!currentContext)
+                {
+                    sharedContextLock = new sf::Lock(mutex);
+                    useSharedContext = true;
+                    sharedContext->setActive(true);
+                }
             }
-            else if (!currentContext)
+
+            ////////////////////////////////////////////////////////////
+            /// \brief Destructor
+            ///
+            ////////////////////////////////////////////////////////////
+            ~TransientContext()
             {
-                sharedContextLock = new sf::Lock(mutex);
-                useSharedContext = true;
-                sharedContext->setActive(true);
+                if (useSharedContext)
+                    sharedContext->setActive(false);
+
+                delete sharedContextLock;
+                delete context;
+            }
+
+            ///////////////////////////////////////////////////////////
+            // Member data
+            ////////////////////////////////////////////////////////////
+            unsigned int referenceCount;
+            sf::Context* context;
+            sf::Lock*    sharedContextLock;
+            bool         useSharedContext;
+        };
+
+        // This per-thread variable tracks if and how a transient
+        // context is currently being used on the current thread
+        sf::ThreadLocalPtr<TransientContext> transientContext(NULL);
+
+        // Supported OpenGL extensions
+        std::vector<std::string> extensions;
+
+        // Load our extensions vector with the supported extensions
+        void loadExtensions()
+        {
+            extensions.clear();
+
+            glGetErrorFuncType glGetErrorFunc = reinterpret_cast<glGetErrorFuncType>(sf::priv::GlContext::getFunction("glGetError"));
+            glGetIntegervFuncType glGetIntegervFunc = reinterpret_cast<glGetIntegervFuncType>(sf::priv::GlContext::getFunction("glGetIntegerv"));
+            glGetStringFuncType glGetStringFunc = reinterpret_cast<glGetStringFuncType>(sf::priv::GlContext::getFunction("glGetString"));
+
+            if (!glGetErrorFunc || !glGetIntegervFunc || !glGetStringFunc)
+                return;
+
+            // Check whether a >= 3.0 context is available
+            int majorVersion = 0;
+            glGetIntegervFunc(GL_MAJOR_VERSION, &majorVersion);
+
+            glGetStringiFuncType glGetStringiFunc = reinterpret_cast<glGetStringiFuncType>(sf::priv::GlContext::getFunction("glGetStringi"));
+
+            if (glGetErrorFunc() == GL_INVALID_ENUM || !glGetStringiFunc)
+            {
+                // Try to load the < 3.0 way
+                const char* extensionString = reinterpret_cast<const char*>(glGetStringFunc(GL_EXTENSIONS));
+
+                do
+                {
+                    const char* extension = extensionString;
+
+                    while (*extensionString && (*extensionString != ' '))
+                        extensionString++;
+
+                    extensions.push_back(std::string(extension, extensionString));
+                }
+                while (*extensionString++);
+            }
+            else
+            {
+                // Try to load the >= 3.0 way
+                int numExtensions = 0;
+                glGetIntegervFunc(GL_NUM_EXTENSIONS, &numExtensions);
+
+                if (numExtensions)
+                {
+                    for (unsigned int i = 0; i < static_cast<unsigned int>(numExtensions); ++i)
+                    {
+                        const char* extensionString = reinterpret_cast<const char*>(glGetStringiFunc(GL_EXTENSIONS, i));
+
+                        extensions.push_back(extensionString);
+                    }
+                }
             }
         }
 
-        ////////////////////////////////////////////////////////////
-        /// \brief Destructor
-        ///
-        ////////////////////////////////////////////////////////////
-        ~TransientContext()
+        // Helper to parse OpenGL version strings
+        bool parseVersionString(const char* version, const char* prefix, unsigned int &major, unsigned int &minor)
         {
-            if (useSharedContext)
-                sharedContext->setActive(false);
+            std::size_t prefixLength = std::strlen(prefix);
 
-            delete sharedContextLock;
-            delete context;
+            if ((std::strlen(version) >= (prefixLength + 3)) &&
+                (std::strncmp(version, prefix, prefixLength) == 0) &&
+                std::isdigit(version[prefixLength]) &&
+                (version[prefixLength + 1] == '.') &&
+                std::isdigit(version[prefixLength + 2]))
+            {
+                major = static_cast<unsigned int>(version[prefixLength] - '0');
+                minor = static_cast<unsigned int>(version[prefixLength + 2] - '0');
+
+                return true;
+            }
+
+            return false;
         }
-
-        ///////////////////////////////////////////////////////////
-        // Member data
-        ////////////////////////////////////////////////////////////
-        unsigned int referenceCount;
-        sf::Context* context;
-        sf::Lock*    sharedContextLock;
-        bool         useSharedContext;
-    };
-
-    // This per-thread variable tracks if and how a transient
-    // context is currently being used on the current thread
-    sf::ThreadLocalPtr<TransientContext> transientContext(NULL);
-
-    // Supported OpenGL extensions
-    std::vector<std::string> extensions;
-
-    // Helper to parse OpenGL version strings
-    bool parseVersionString(const char* version, const char* prefix, unsigned int &major, unsigned int &minor)
-    {
-        std::size_t prefixLength = std::strlen(prefix);
-
-        if ((std::strlen(version) >= (prefixLength + 3)) &&
-            (std::strncmp(version, prefix, prefixLength) == 0) &&
-            std::isdigit(version[prefixLength]) &&
-            (version[prefixLength + 1] == '.') &&
-            std::isdigit(version[prefixLength + 2]))
-        {
-            major = version[prefixLength] - '0';
-            minor = version[prefixLength + 2] - '0';
-
-            return true;
-        }
-
-        return false;
     }
 }
 
@@ -241,6 +323,12 @@ namespace priv
 ////////////////////////////////////////////////////////////
 void GlContext::initResource()
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::resourceCount;
+    using GlContextImpl::currentContext;
+    using GlContextImpl::sharedContext;
+    using GlContextImpl::loadExtensions;
+
     // Protect from concurrent access
     Lock lock(mutex);
 
@@ -260,50 +348,7 @@ void GlContext::initResource()
         sharedContext->initialize(ContextSettings());
 
         // Load our extensions vector
-        extensions.clear();
-
-        // Check whether a >= 3.0 context is available
-        int majorVersion = 0;
-        glGetIntegerv(GL_MAJOR_VERSION, &majorVersion);
-
-        if (glGetError() == GL_INVALID_ENUM)
-        {
-            // Try to load the < 3.0 way
-            const char* extensionString = reinterpret_cast<const char*>(glGetString(GL_EXTENSIONS));
-
-            do
-            {
-                const char* extension = extensionString;
-
-                while(*extensionString && (*extensionString != ' '))
-                    extensionString++;
-
-                extensions.push_back(std::string(extension, extensionString));
-            }
-            while (*extensionString++);
-        }
-        else
-        {
-            // Try to load the >= 3.0 way
-            glGetStringiFuncType glGetStringiFunc = NULL;
-            glGetStringiFunc = reinterpret_cast<glGetStringiFuncType>(getFunction("glGetStringi"));
-
-            if (glGetStringiFunc)
-            {
-                int numExtensions = 0;
-                glGetIntegerv(GL_NUM_EXTENSIONS, &numExtensions);
-
-                if (numExtensions)
-                {
-                    for (unsigned int i = 0; i < static_cast<unsigned int>(numExtensions); ++i)
-                    {
-                        const char* extensionString = reinterpret_cast<const char*>(glGetStringiFunc(GL_EXTENSIONS, i));
-
-                        extensions.push_back(extensionString);
-                    }
-                }
-            }
-        }
+        loadExtensions();
 
         // Deactivate the shared context so that others can activate it when necessary
         sharedContext->setActive(false);
@@ -317,6 +362,10 @@ void GlContext::initResource()
 ////////////////////////////////////////////////////////////
 void GlContext::cleanupResource()
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::resourceCount;
+    using GlContextImpl::sharedContext;
+
     // Protect from concurrent access
     Lock lock(mutex);
 
@@ -339,13 +388,17 @@ void GlContext::cleanupResource()
 ////////////////////////////////////////////////////////////
 void GlContext::registerContextDestroyCallback(ContextDestroyCallback callback, void* arg)
 {
-    contextDestroyCallbacks.insert(std::make_pair(callback, arg));
+    GlContextImpl::contextDestroyCallbacks.insert(std::make_pair(callback, arg));
 }
 
 
 ////////////////////////////////////////////////////////////
 void GlContext::acquireTransientContext()
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::TransientContext;
+    using GlContextImpl::transientContext;
+
     // Protect from concurrent access
     Lock lock(mutex);
 
@@ -362,6 +415,9 @@ void GlContext::acquireTransientContext()
 ////////////////////////////////////////////////////////////
 void GlContext::releaseTransientContext()
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::transientContext;
+
     // Protect from concurrent access
     Lock lock(mutex);
 
@@ -384,6 +440,9 @@ void GlContext::releaseTransientContext()
 ////////////////////////////////////////////////////////////
 GlContext* GlContext::create()
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::sharedContext;
+
     // Make sure that there's an active context (context creation may need extensions, and thus a valid context)
     assert(sharedContext != NULL);
 
@@ -412,11 +471,35 @@ GlContext* GlContext::create()
 ////////////////////////////////////////////////////////////
 GlContext* GlContext::create(const ContextSettings& settings, const WindowImpl* owner, unsigned int bitsPerPixel)
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::resourceCount;
+    using GlContextImpl::sharedContext;
+    using GlContextImpl::loadExtensions;
+
     // Make sure that there's an active context (context creation may need extensions, and thus a valid context)
     assert(sharedContext != NULL);
 
     Lock lock(mutex);
 
+    // If resourceCount is 1 we know that we are inside sf::Context or sf::Window
+    // Only in this situation we allow the user to indirectly re-create the shared context as a core context
+
+    // Check if we need to convert our shared context into a core context
+    if ((resourceCount == 1) &&
+        (settings.attributeFlags & ContextSettings::Core) &&
+        !(sharedContext->m_settings.attributeFlags & ContextSettings::Core))
+    {
+        // Re-create our shared context as a core context
+        ContextSettings sharedSettings(0, 0, 0, settings.majorVersion, settings.minorVersion, settings.attributeFlags);
+
+        delete sharedContext;
+        sharedContext = new ContextType(NULL, sharedSettings, 1, 1);
+        sharedContext->initialize(sharedSettings);
+
+        // Reload our extensions vector
+        loadExtensions();
+    }
+
     GlContext* context = NULL;
 
     // We don't use acquireTransientContext here since we have
@@ -441,11 +524,35 @@ GlContext* GlContext::create(const ContextSettings& settings, const WindowImpl*
 ////////////////////////////////////////////////////////////
 GlContext* GlContext::create(const ContextSettings& settings, unsigned int width, unsigned int height)
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::resourceCount;
+    using GlContextImpl::sharedContext;
+    using GlContextImpl::loadExtensions;
+
     // Make sure that there's an active context (context creation may need extensions, and thus a valid context)
     assert(sharedContext != NULL);
 
     Lock lock(mutex);
 
+    // If resourceCount is 1 we know that we are inside sf::Context or sf::Window
+    // Only in this situation we allow the user to indirectly re-create the shared context as a core context
+
+    // Check if we need to convert our shared context into a core context
+    if ((resourceCount == 1) &&
+        (settings.attributeFlags & ContextSettings::Core) &&
+        !(sharedContext->m_settings.attributeFlags & ContextSettings::Core))
+    {
+        // Re-create our shared context as a core context
+        ContextSettings sharedSettings(0, 0, 0, settings.majorVersion, settings.minorVersion, settings.attributeFlags);
+
+        delete sharedContext;
+        sharedContext = new ContextType(NULL, sharedSettings, 1, 1);
+        sharedContext->initialize(sharedSettings);
+
+        // Reload our extensions vector
+        loadExtensions();
+    }
+
     GlContext* context = NULL;
 
     // We don't use acquireTransientContext here since we have
@@ -470,6 +577,7 @@ GlContext* GlContext::create(const ContextSettings& settings, unsigned int width
 ////////////////////////////////////////////////////////////
 bool GlContext::isExtensionAvailable(const char* name)
 {
+    using GlContextImpl::extensions;
     return std::find(extensions.begin(), extensions.end(), name) != extensions.end();
 }
 
@@ -477,23 +585,24 @@ bool GlContext::isExtensionAvailable(const char* name)
 ////////////////////////////////////////////////////////////
 GlFunctionPointer GlContext::getFunction(const char* name)
 {
-#if !defined(SFML_OPENGL_ES)
-
-    Lock lock(mutex);
+    Lock lock(GlContextImpl::mutex);
 
     return ContextType::getFunction(name);
+}
 
-#else
 
-    return 0;
-
-#endif
+////////////////////////////////////////////////////////////
+const GlContext* GlContext::getActiveContext()
+{
+    using GlContextImpl::currentContext;
+    return currentContext;
 }
 
 
 ////////////////////////////////////////////////////////////
 Uint64 GlContext::getActiveContextId()
 {
+    using GlContextImpl::currentContext;
     return currentContext ? currentContext->m_id : 0;
 }
 
@@ -501,6 +610,9 @@ Uint64 GlContext::getActiveContextId()
 ////////////////////////////////////////////////////////////
 GlContext::~GlContext()
 {
+    using GlContextImpl::currentContext;
+    using GlContextImpl::sharedContext;
+
     // Deactivate the context before killing it, unless we're inside Cleanup()
     if (sharedContext)
     {
@@ -520,6 +632,10 @@ const ContextSettings& GlContext::getSettings() const
 ////////////////////////////////////////////////////////////
 bool GlContext::setActive(bool active)
 {
+    using GlContextImpl::mutex;
+    using GlContextImpl::currentContext;
+    using GlContextImpl::sharedContext;
+
     if (active)
     {
         if (this != currentContext)
@@ -572,7 +688,7 @@ bool GlContext::setActive(bool active)
 
 ////////////////////////////////////////////////////////////
 GlContext::GlContext() :
-m_id(id++)
+m_id(GlContextImpl::id++)
 {
     // Nothing to do
 }
@@ -610,6 +726,10 @@ int GlContext::evaluateFormat(unsigned int bitsPerPixel, const ContextSettings&
 ////////////////////////////////////////////////////////////
 void GlContext::cleanupUnsharedResources()
 {
+    using GlContextImpl::currentContext;
+    using GlContextImpl::ContextDestroyCallbacks;
+    using GlContextImpl::contextDestroyCallbacks;
+
     // Save the current context so we can restore it later
     GlContext* contextToRestore = currentContext;
 
@@ -641,10 +761,22 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
     int minorVersion = 0;
 
     // Try the new way first
-    glGetIntegerv(GL_MAJOR_VERSION, &majorVersion);
-    glGetIntegerv(GL_MINOR_VERSION, &minorVersion);
+    glGetIntegervFuncType glGetIntegervFunc = reinterpret_cast<glGetIntegervFuncType>(getFunction("glGetIntegerv"));
+    glGetErrorFuncType glGetErrorFunc = reinterpret_cast<glGetErrorFuncType>(getFunction("glGetError"));
+    glGetStringFuncType glGetStringFunc = reinterpret_cast<glGetStringFuncType>(getFunction("glGetString"));
+    glEnableFuncType glEnableFunc = reinterpret_cast<glEnableFuncType>(getFunction("glEnable"));
+    glIsEnabledFuncType glIsEnabledFunc = reinterpret_cast<glIsEnabledFuncType>(getFunction("glIsEnabled"));
 
-    if (glGetError() != GL_INVALID_ENUM)
+    if (!glGetIntegervFunc || !glGetErrorFunc || !glGetStringFunc || !glEnableFunc || !glIsEnabledFunc)
+    {
+        err() << "Could not load necessary function to initialize OpenGL context" << std::endl;
+        return;
+    }
+
+    glGetIntegervFunc(GL_MAJOR_VERSION, &majorVersion);
+    glGetIntegervFunc(GL_MINOR_VERSION, &minorVersion);
+
+    if (glGetErrorFunc() != GL_INVALID_ENUM)
     {
         m_settings.majorVersion = static_cast<unsigned int>(majorVersion);
         m_settings.minorVersion = static_cast<unsigned int>(minorVersion);
@@ -657,7 +789,7 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
         m_settings.majorVersion = 1;
         m_settings.minorVersion = 1;
 
-        const char* version = reinterpret_cast<const char*>(glGetString(GL_VERSION));
+        const char* version = reinterpret_cast<const char*>(glGetStringFunc(GL_VERSION));
         if (version)
         {
             // OpenGL ES Common Lite profile: The beginning of the returned string is "OpenGL ES-CL major.minor"
@@ -665,6 +797,8 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
             // OpenGL ES Full profile:        The beginning of the returned string is "OpenGL ES major.minor"
             // Desktop OpenGL:                The beginning of the returned string is "major.minor"
 
+            using GlContextImpl::parseVersionString;
+
             if (!parseVersionString(version, "OpenGL ES-CL ", m_settings.majorVersion, m_settings.minorVersion) &&
                 !parseVersionString(version, "OpenGL ES-CM ", m_settings.majorVersion, m_settings.minorVersion) &&
                 !parseVersionString(version, "OpenGL ES ",    m_settings.majorVersion, m_settings.minorVersion) &&
@@ -701,7 +835,7 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
     {
         // Retrieve the context flags
         int flags = 0;
-        glGetIntegerv(GL_CONTEXT_FLAGS, &flags);
+        glGetIntegervFunc(GL_CONTEXT_FLAGS, &flags);
 
         if (flags & GL_CONTEXT_FLAG_DEBUG_BIT)
             m_settings.attributeFlags |= ContextSettings::Debug;
@@ -715,7 +849,7 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
             if (glGetStringiFunc)
             {
                 int numExtensions = 0;
-                glGetIntegerv(GL_NUM_EXTENSIONS, &numExtensions);
+                glGetIntegervFunc(GL_NUM_EXTENSIONS, &numExtensions);
 
                 for (unsigned int i = 0; i < static_cast<unsigned int>(numExtensions); ++i)
                 {
@@ -733,7 +867,7 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
         {
             // Retrieve the context profile
             int profile = 0;
-            glGetIntegerv(GL_CONTEXT_PROFILE_MASK, &profile);
+            glGetIntegervFunc(GL_CONTEXT_PROFILE_MASK, &profile);
 
             if (profile & GL_CONTEXT_CORE_PROFILE_BIT)
                 m_settings.attributeFlags |= ContextSettings::Core;
@@ -743,7 +877,7 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
     // Enable anti-aliasing if requested by the user and supported
     if ((requestedSettings.antialiasingLevel > 0) && (m_settings.antialiasingLevel > 0))
     {
-        glEnable(GL_MULTISAMPLE);
+        glEnableFunc(GL_MULTISAMPLE);
     }
     else
     {
@@ -753,10 +887,10 @@ void GlContext::initialize(const ContextSettings& requestedSettings)
     // Enable sRGB if requested by the user and supported
     if (requestedSettings.sRgbCapable && m_settings.sRgbCapable)
     {
-        glEnable(GL_FRAMEBUFFER_SRGB);
+        glEnableFunc(GL_FRAMEBUFFER_SRGB);
 
         // Check to see if the enable was successful
-        if (glIsEnabled(GL_FRAMEBUFFER_SRGB) == GL_FALSE)
+        if (glIsEnabledFunc(GL_FRAMEBUFFER_SRGB) == GL_FALSE)
         {
             err() << "Warning: Failed to enable GL_FRAMEBUFFER_SRGB" << std::endl;
             m_settings.sRgbCapable = false;
@@ -774,9 +908,18 @@ void GlContext::checkSettings(const ContextSettings& requestedSettings)
 {
     // Perform checks to inform the user if they are getting a context they might not have expected
 
+    glGetStringFuncType glGetStringFunc = reinterpret_cast<glGetStringFuncType>(getFunction("glGetString"));
+
+    if (!glGetStringFunc)
+    {
+        err() << "Could not load glGetString function" << std::endl;
+
+        return;
+    }
+
     // Detect any known non-accelerated implementations and warn
-    const char* vendorName = reinterpret_cast<const char*>(glGetString(GL_VENDOR));
-    const char* rendererName = reinterpret_cast<const char*>(glGetString(GL_RENDERER));
+    const char* vendorName = reinterpret_cast<const char*>(glGetStringFunc(GL_VENDOR));
+    const char* rendererName = reinterpret_cast<const char*>(glGetStringFunc(GL_RENDERER));
 
     if (vendorName && rendererName)
     {
@@ -787,8 +930,8 @@ void GlContext::checkSettings(const ContextSettings& requestedSettings)
         }
     }
 
-    int version = m_settings.majorVersion * 10 + m_settings.minorVersion;
-    int requestedVersion = requestedSettings.majorVersion * 10 + requestedSettings.minorVersion;
+    int version = static_cast<int>(m_settings.majorVersion * 10u + m_settings.minorVersion);
+    int requestedVersion = static_cast<int>(requestedSettings.majorVersion * 10u + requestedSettings.minorVersion);
 
     if ((m_settings.attributeFlags    != requestedSettings.attributeFlags)    ||
         (version                      <  requestedVersion)                    ||
