@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Marco Antognini (antognini.marco@gmail.com),
+// Copyright (C) 2007-2023 Marco Antognini (antognini.marco@gmail.com),
 //                         Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
@@ -28,6 +28,7 @@
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/VideoMode.hpp>
 #include <SFML/Window/Window.hpp>
+#include <SFML/Window/OSX/AutoreleasePoolWrapper.hpp>
 #include <SFML/Window/OSX/InputImpl.hpp>
 #include <SFML/Window/OSX/HIDInputManager.hpp>
 #include <SFML/System/Err.hpp>
@@ -39,9 +40,6 @@
 /// In order to keep track of the keyboard's state and mouse buttons' state
 /// we use the HID manager. Mouse position is handled differently.
 ///
-/// NB: we probably could use
-/// NSEvent +addGlobalMonitorForEventsMatchingMask:handler: for mouse only.
-///
 ////////////////////////////////////////////////////////////
 
 namespace sf
@@ -55,9 +53,9 @@ namespace priv
 /// \return nil if something went wrong or a SFOpenGLView*.
 ///
 ////////////////////////////////////////////////////////////
-SFOpenGLView* getSFOpenGLViewFromSFMLWindow(const Window& window)
+SFOpenGLView* getSFOpenGLViewFromSFMLWindow(const WindowBase& window)
 {
-    id nsHandle = (id)window.getSystemHandle();
+    id nsHandle = static_cast<id>(window.getSystemHandle());
 
     // Get our SFOpenGLView from ...
     SFOpenGLView* view = nil;
@@ -77,7 +75,7 @@ SFOpenGLView* getSFOpenGLViewFromSFMLWindow(const Window& window)
                 {
                     if ([subview isKindOfClass:[SFOpenGLView class]])
                     {
-                        view = (SFOpenGLView*)subview;
+                        view = static_cast<SFOpenGLView*>(subview);
                         break;
                     }
                 }
@@ -101,7 +99,7 @@ SFOpenGLView* getSFOpenGLViewFromSFMLWindow(const Window& window)
         {
             if ([subview isKindOfClass:[SFOpenGLView class]])
             {
-                view = (SFOpenGLView*)subview;
+                view = static_cast<SFOpenGLView*>(subview);
                 break;
             }
         }
@@ -122,13 +120,43 @@ SFOpenGLView* getSFOpenGLViewFromSFMLWindow(const Window& window)
     return view;
 }
 
+
 ////////////////////////////////////////////////////////////
 bool InputImpl::isKeyPressed(Keyboard::Key key)
 {
+    AutoreleasePool pool;
     return HIDInputManager::getInstance().isKeyPressed(key);
 }
 
 
+////////////////////////////////////////////////////////////
+bool InputImpl::isKeyPressed(Keyboard::Scancode code)
+{
+    return HIDInputManager::getInstance().isKeyPressed(code);
+}
+
+
+////////////////////////////////////////////////////////////
+Keyboard::Key InputImpl::localize(Keyboard::Scancode code)
+{
+    return HIDInputManager::getInstance().localize(code);
+}
+
+
+////////////////////////////////////////////////////////////
+Keyboard::Scancode InputImpl::delocalize(Keyboard::Key key)
+{
+    return HIDInputManager::getInstance().delocalize(key);
+}
+
+
+////////////////////////////////////////////////////////////
+String InputImpl::getDescription(Keyboard::Scancode code)
+{
+    return HIDInputManager::getInstance().getDescription(code);
+}
+
+
 ////////////////////////////////////////////////////////////
 void InputImpl::setVirtualKeyboardVisible(bool /*visible*/)
 {
@@ -139,6 +167,7 @@ void InputImpl::setVirtualKeyboardVisible(bool /*visible*/)
 ////////////////////////////////////////////////////////////
 bool InputImpl::isMouseButtonPressed(Mouse::Button button)
 {
+    AutoreleasePool pool;
     NSUInteger state = [NSEvent pressedMouseButtons];
     NSUInteger flag = 1 << button;
     return (state & flag) != 0;
@@ -148,18 +177,20 @@ bool InputImpl::isMouseButtonPressed(Mouse::Button button)
 ////////////////////////////////////////////////////////////
 Vector2i InputImpl::getMousePosition()
 {
+    AutoreleasePool pool;
     // Reverse Y axis to match SFML coord.
     NSPoint pos = [NSEvent mouseLocation];
     pos.y = sf::VideoMode::getDesktopMode().height - pos.y;
 
-    int scale = [[NSScreen mainScreen] backingScaleFactor];
-    return Vector2i(pos.x, pos.y) * scale;
+    int scale = static_cast<int>([[NSScreen mainScreen] backingScaleFactor]);
+    return Vector2i(static_cast<int>(pos.x), static_cast<int>(pos.y)) * scale;
 }
 
 
 ////////////////////////////////////////////////////////////
-Vector2i InputImpl::getMousePosition(const Window& relativeTo)
+Vector2i InputImpl::getMousePosition(const WindowBase& relativeTo)
 {
+    AutoreleasePool pool;
     SFOpenGLView* view = getSFOpenGLViewFromSFMLWindow(relativeTo);
 
     // No view ?
@@ -169,16 +200,17 @@ Vector2i InputImpl::getMousePosition(const Window& relativeTo)
     // Use -cursorPositionFromEvent: with nil.
     NSPoint pos = [view cursorPositionFromEvent:nil];
 
-    int scale = [view displayScaleFactor];
-    return Vector2i(pos.x, pos.y) * scale;
+    int scale = static_cast<int>([view displayScaleFactor]);
+    return Vector2i(static_cast<int>(pos.x), static_cast<int>(pos.y)) * scale;
 }
 
 
 ////////////////////////////////////////////////////////////
 void InputImpl::setMousePosition(const Vector2i& position)
 {
+    AutoreleasePool pool;
     // Here we don't need to reverse the coordinates.
-    int scale = [[NSScreen mainScreen] backingScaleFactor];
+    int scale = static_cast<int>([[NSScreen mainScreen] backingScaleFactor]);
     CGPoint pos = CGPointMake(position.x / scale, position.y / scale);
 
     // Place the cursor.
@@ -193,8 +225,9 @@ void InputImpl::setMousePosition(const Vector2i& position)
 
 
 ////////////////////////////////////////////////////////////
-void InputImpl::setMousePosition(const Vector2i& position, const Window& relativeTo)
+void InputImpl::setMousePosition(const Vector2i& position, const WindowBase& relativeTo)
 {
+    AutoreleasePool pool;
     SFOpenGLView* view = getSFOpenGLViewFromSFMLWindow(relativeTo);
 
     // No view ?
@@ -202,10 +235,10 @@ void InputImpl::setMousePosition(const Vector2i& position, const Window& relativ
         return;
 
     // Let SFOpenGLView compute the position in global coordinate
-    int scale = [view displayScaleFactor];
+    int scale = static_cast<int>([view displayScaleFactor]);
     NSPoint p = NSMakePoint(position.x / scale, position.y / scale);
     p = [view computeGlobalPositionOfRelativePoint:p];
-    setMousePosition(sf::Vector2i(p.x, p.y) * scale);
+    setMousePosition(sf::Vector2i(static_cast<int>(p.x), static_cast<int>(p.y)) * scale);
 }
 
 
@@ -226,7 +259,7 @@ Vector2i InputImpl::getTouchPosition(unsigned int /*finger*/)
 
 
 ////////////////////////////////////////////////////////////
-Vector2i InputImpl::getTouchPosition(unsigned int /*finger*/, const Window& /*relativeTo*/)
+Vector2i InputImpl::getTouchPosition(unsigned int /*finger*/, const WindowBase& /*relativeTo*/)
 {
     // Not applicable
     return Vector2i();
