@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -33,6 +33,14 @@
 #include <SFML/System/Err.hpp>
 #include <vector>
 
+// We check for this definition in order to avoid multiple definitions of GLAD
+// entities during unity builds of SFML.
+#ifndef SF_GLAD_GLX_IMPLEMENTATION_INCLUDED
+#define SF_GLAD_GLX_IMPLEMENTATION_INCLUDED
+#define SF_GLAD_GLX_IMPLEMENTATION
+#include <glad/glx.h>
+#endif
+
 #if !defined(GLX_DEBUGGING) && defined(SFML_DEBUG)
     // Enable this to print messages to err() everytime GLX produces errors
     //#define GLX_DEBUGGING
@@ -43,12 +51,31 @@ namespace
     sf::Mutex glxErrorMutex;
     bool glxErrorOccurred = false;
 
+
+    ////////////////////////////////////////////////////////////
+    void ensureExtensionsInit(::Display* display, int screen)
+    {
+        static bool initialized = false;
+        if (!initialized)
+        {
+            initialized = true;
+
+            // We don't check the return value since the extension
+            // flags are cleared even if loading fails
+            gladLoaderLoadGLX(display, screen);
+
+            gladLoadGLX(display, screen, sf::priv::GlxContext::getFunction);
+        }
+    }
+
+
     int HandleXError(::Display*, XErrorEvent*)
     {
         glxErrorOccurred = true;
         return 0;
     }
 
+
     class GlxErrorHandler
     {
     public:
@@ -79,21 +106,6 @@ namespace sf
 {
 namespace priv
 {
-////////////////////////////////////////////////////////////
-void ensureExtensionsInit(::Display* display, int screen)
-{
-    static bool initialized = false;
-    if (!initialized)
-    {
-        initialized = true;
-
-        // We don't check the return value since the extension
-        // flags are cleared even if loading fails
-        sfglx_LoadFunctions(display, screen);
-    }
-}
-
-
 ////////////////////////////////////////////////////////////
 GlxContext::GlxContext(GlxContext* shared) :
 m_display   (NULL),
@@ -120,7 +132,7 @@ m_ownsWindow(false)
 
 
 ////////////////////////////////////////////////////////////
-GlxContext::GlxContext(GlxContext* shared, const ContextSettings& settings, const WindowImpl* owner, unsigned int bitsPerPixel) :
+GlxContext::GlxContext(GlxContext* shared, const ContextSettings& settings, const WindowImpl* owner, unsigned int /*bitsPerPixel*/) :
 m_display   (NULL),
 m_window    (0),
 m_context   (NULL),
@@ -137,7 +149,7 @@ m_ownsWindow(false)
     ensureExtensionsInit(m_display, DefaultScreen(m_display));
 
     // Create the rendering surface from the owner window
-    createSurface(static_cast< ::Window>(owner->getSystemHandle()));
+    createSurface(owner->getSystemHandle());
 
     // Create the context
     createContext(shared);
@@ -212,7 +224,7 @@ GlxContext::~GlxContext()
 ////////////////////////////////////////////////////////////
 GlFunctionPointer GlxContext::getFunction(const char* name)
 {
-    return reinterpret_cast<GlFunctionPointer>(glXGetProcAddressARB(reinterpret_cast<const GLubyte*>(name)));
+    return glXGetProcAddress(reinterpret_cast<const GLubyte*>(name));
 }
 
 
@@ -281,15 +293,15 @@ void GlxContext::setVerticalSyncEnabled(bool enabled)
     // We use the direct pointer to the MESA entry point instead of the alias
     // because glx.h declares the entry point as an external function
     // which would require us to link in an additional library
-    if (sfglx_ext_EXT_swap_control == sfglx_LOAD_SUCCEEDED)
+    if (SF_GLAD_GLX_EXT_swap_control)
     {
         glXSwapIntervalEXT(m_display, m_pbuffer ? m_pbuffer : m_window, enabled ? 1 : 0);
     }
-    else if (sfglx_ext_MESA_swap_control == sfglx_LOAD_SUCCEEDED)
+    else if (SF_GLAD_GLX_MESA_swap_control)
     {
-        result = sf_ptrc_glXSwapIntervalMESA(enabled ? 1 : 0);
+        result = glXSwapIntervalMESA(enabled ? 1 : 0);
     }
-    else if (sfglx_ext_SGI_swap_control == sfglx_LOAD_SUCCEEDED)
+    else if (SF_GLAD_GLX_SGI_swap_control)
     {
         result = glXSwapIntervalSGI(enabled ? 1 : 0);
     }
@@ -316,6 +328,8 @@ XVisualInfo GlxContext::selectBestVisual(::Display* display, unsigned int bitsPe
     // Make sure that extensions are initialized
     ensureExtensionsInit(display, DefaultScreen(display));
 
+    const int screen = DefaultScreen(display);
+
     // Retrieve all the visuals
     int count;
     XVisualInfo* visuals = XGetVisualInfo(display, 0, NULL, &count);
@@ -326,6 +340,10 @@ XVisualInfo GlxContext::selectBestVisual(::Display* display, unsigned int bitsPe
         XVisualInfo bestVisual = XVisualInfo();
         for (int i = 0; i < count; ++i)
         {
+            // Filter by screen
+            if (visuals[i].screen != screen)
+                continue;
+
             // Check mandatory attributes
             int doubleBuffer;
             glXGetConfig(display, &visuals[i], GLX_DOUBLEBUFFER, &doubleBuffer);
@@ -341,7 +359,7 @@ XVisualInfo GlxContext::selectBestVisual(::Display* display, unsigned int bitsPe
             glXGetConfig(display, &visuals[i], GLX_DEPTH_SIZE,   &depth);
             glXGetConfig(display, &visuals[i], GLX_STENCIL_SIZE, &stencil);
 
-            if (sfglx_ext_ARB_multisample == sfglx_LOAD_SUCCEEDED)
+            if (SF_GLAD_GLX_ARB_multisample)
             {
                 glXGetConfig(display, &visuals[i], GLX_SAMPLE_BUFFERS_ARB, &multiSampling);
                 glXGetConfig(display, &visuals[i], GLX_SAMPLES_ARB,        &samples);
@@ -352,7 +370,7 @@ XVisualInfo GlxContext::selectBestVisual(::Display* display, unsigned int bitsPe
                 samples = 0;
             }
 
-            if ((sfglx_ext_EXT_framebuffer_sRGB == sfglx_LOAD_SUCCEEDED) || (sfglx_ext_ARB_framebuffer_sRGB == sfglx_LOAD_SUCCEEDED))
+            if (SF_GLAD_GLX_EXT_framebuffer_sRGB || SF_GLAD_GLX_ARB_framebuffer_sRGB)
             {
                 glXGetConfig(display, &visuals[i], GLX_FRAMEBUFFER_SRGB_CAPABLE_ARB, &sRgb);
             }
@@ -399,7 +417,7 @@ void GlxContext::updateSettingsFromVisualInfo(XVisualInfo* visualInfo)
     glXGetConfig(m_display, visualInfo, GLX_DEPTH_SIZE,   &depth);
     glXGetConfig(m_display, visualInfo, GLX_STENCIL_SIZE, &stencil);
 
-    if (sfglx_ext_ARB_multisample == sfglx_LOAD_SUCCEEDED)
+    if (SF_GLAD_GLX_ARB_multisample)
     {
         glXGetConfig(m_display, visualInfo, GLX_SAMPLE_BUFFERS_ARB, &multiSampling);
         glXGetConfig(m_display, visualInfo, GLX_SAMPLES_ARB,        &samples);
@@ -410,7 +428,7 @@ void GlxContext::updateSettingsFromVisualInfo(XVisualInfo* visualInfo)
         samples = 0;
     }
 
-    if ((sfglx_ext_EXT_framebuffer_sRGB == sfglx_LOAD_SUCCEEDED) || (sfglx_ext_ARB_framebuffer_sRGB == sfglx_LOAD_SUCCEEDED))
+    if (SF_GLAD_GLX_EXT_framebuffer_sRGB || SF_GLAD_GLX_ARB_framebuffer_sRGB)
     {
         glXGetConfig(m_display, visualInfo, GLX_FRAMEBUFFER_SRGB_CAPABLE_ARB, &sRgb);
     }
@@ -421,7 +439,7 @@ void GlxContext::updateSettingsFromVisualInfo(XVisualInfo* visualInfo)
 
     m_settings.depthBits         = static_cast<unsigned int>(depth);
     m_settings.stencilBits       = static_cast<unsigned int>(stencil);
-    m_settings.antialiasingLevel = multiSampling ? samples : 0;
+    m_settings.antialiasingLevel = multiSampling ? static_cast<unsigned int>(samples) : 0;
     m_settings.sRgbCapable       = (sRgb == True);
 }
 
@@ -460,7 +478,7 @@ void GlxContext::createSurface(GlxContext* shared, unsigned int width, unsigned
     XVisualInfo visualInfo = selectBestVisual(m_display, bitsPerPixel, m_settings);
 
     // Check if the shared context already exists and pbuffers are supported
-    if (shared && (sfglx_ext_SGIX_pbuffer == sfglx_LOAD_SUCCEEDED))
+    if (shared && SF_GLAD_GLX_SGIX_pbuffer)
     {
         // There are no GLX versions prior to 1.0
         int major = 0;
@@ -529,6 +547,9 @@ void GlxContext::createSurface(GlxContext* shared, unsigned int width, unsigned
     XSetWindowAttributes attributes;
     attributes.colormap = XCreateColormap(m_display, RootWindow(m_display, screen), visualInfo.visual, AllocNone);
 
+    // Note: bitsPerPixel is explicitly ignored. Instead, DefaultDepth() is used in order to avoid window creation failure due to
+    // a depth not supported by the X window system. On Unix/Linux, the window's pixel format is not directly associated with the
+    // rendering surface (unlike on Windows, for example).
     m_window = XCreateWindow(m_display,
                              RootWindow(m_display, screen),
                              0, 0,
@@ -620,7 +641,7 @@ void GlxContext::createContext(GlxContext* shared)
         err() << "Failed to query GLX version, limited to legacy context creation" << std::endl;
 
     // Check if glXCreateContextAttribsARB is available (requires GLX 1.3 or greater)
-    bool hasCreateContextArb = (sfglx_ext_ARB_create_context == sfglx_LOAD_SUCCEEDED) && ((major > 1) || (minor >= 3));
+    bool hasCreateContextArb = SF_GLAD_GLX_ARB_create_context && ((major > 1) || (minor >= 3));
 
     // Create the OpenGL context -- first try using glXCreateContextAttribsARB
     if (hasCreateContextArb)
@@ -662,13 +683,13 @@ void GlxContext::createContext(GlxContext* shared)
             if ((m_settings.majorVersion > 1) || ((m_settings.majorVersion == 1) && (m_settings.minorVersion > 1)))
             {
                 attributes.push_back(GLX_CONTEXT_MAJOR_VERSION_ARB);
-                attributes.push_back(m_settings.majorVersion);
+                attributes.push_back(static_cast<int>(m_settings.majorVersion));
                 attributes.push_back(GLX_CONTEXT_MINOR_VERSION_ARB);
-                attributes.push_back(m_settings.minorVersion);
+                attributes.push_back(static_cast<int>(m_settings.minorVersion));
             }
 
             // Check if setting the profile is supported
-            if (sfglx_ext_ARB_create_context_profile == sfglx_LOAD_SUCCEEDED)
+            if (SF_GLAD_GLX_ARB_create_context_profile)
             {
                 int profile = (m_settings.attributeFlags & ContextSettings::Core) ? GLX_CONTEXT_CORE_PROFILE_BIT_ARB : GLX_CONTEXT_COMPATIBILITY_PROFILE_BIT_ARB;
                 int debug = (m_settings.attributeFlags & ContextSettings::Debug) ? GLX_CONTEXT_DEBUG_BIT_ARB : 0;
