@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -45,19 +45,37 @@ class InputImpl
 public:
 
     ////////////////////////////////////////////////////////////
-    /// \brief Check if a key is pressed
-    ///
-    /// \param key Key to check
-    ///
-    /// \return True if the key is pressed, false otherwise
+    /// \copydoc sf::Keyboard::isKeyPressed(Key)
     ///
     ////////////////////////////////////////////////////////////
     static bool isKeyPressed(Keyboard::Key key);
 
     ////////////////////////////////////////////////////////////
-    /// \brief Show or hide the virtual keyboard
+    /// \copydoc sf::Keyboard::isKeyPressed(Scancode)
     ///
-    /// \param visible True to show, false to hide
+    ////////////////////////////////////////////////////////////
+    static bool isKeyPressed(Keyboard::Scancode code);
+
+    ////////////////////////////////////////////////////////////
+    /// \copydoc sf::Keyboard::localize
+    ///
+    ////////////////////////////////////////////////////////////
+    static Keyboard::Key localize(Keyboard::Scancode code);
+
+    ////////////////////////////////////////////////////////////
+    /// \copydoc sf::Keyboard::delocalize
+    ///
+    ////////////////////////////////////////////////////////////
+    static Keyboard::Scancode delocalize(Keyboard::Key key);
+
+    ////////////////////////////////////////////////////////////
+    /// \copydoc sf::Keyboard::getDescription
+    ///
+    ////////////////////////////////////////////////////////////
+    static String getDescription(Keyboard::Scancode code);
+
+    ////////////////////////////////////////////////////////////
+    /// \copydoc sf::Keyboard::setVirtualKeyboardVisible
     ///
     ////////////////////////////////////////////////////////////
     static void setVirtualKeyboardVisible(bool visible);
@@ -95,7 +113,7 @@ public:
     /// \return Current position of the mouse
     ///
     ////////////////////////////////////////////////////////////
-    static Vector2i getMousePosition(const Window& relativeTo);
+    static Vector2i getMousePosition(const WindowBase& relativeTo);
 
     ////////////////////////////////////////////////////////////
     /// \brief Set the current position of the mouse in desktop coordinates
@@ -120,7 +138,7 @@ public:
     /// \param relativeTo Reference window
     ///
     ////////////////////////////////////////////////////////////
-    static void setMousePosition(const Vector2i& position, const Window& relativeTo);
+    static void setMousePosition(const Vector2i& position, const WindowBase& relativeTo);
 
     ////////////////////////////////////////////////////////////
     /// \brief Check if a touch event is currently down
@@ -157,7 +175,7 @@ public:
     /// \return Current position of \a finger, or undefined if it's not down
     ///
     ////////////////////////////////////////////////////////////
-    static Vector2i getTouchPosition(unsigned int finger, const Window& relativeTo);
+    static Vector2i getTouchPosition(unsigned int finger, const WindowBase& relativeTo);
 };
 
 } // namespace priv
