@@ -26,10 +26,26 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/Win32/ClipboardImpl.hpp>
+#include <SFML/System/Err.hpp>
 #include <SFML/System/String.hpp>
 #include <iostream>
 #include <windows.h>
 
+namespace
+{
+    std::string getErrorString(DWORD error)
+    {
+        PTCHAR buffer;
+
+        if (FormatMessage(FORMAT_MESSAGE_MAX_WIDTH_MASK | FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, NULL, error, 0, reinterpret_cast<PTCHAR>(&buffer), 0, NULL) == 0)
+            return "Unknown error.";
+
+        sf::String message = buffer;
+        LocalFree(buffer);
+        return message.toAnsiString();
+    }
+}
+
 
 namespace sf
 {
@@ -42,13 +58,13 @@ String ClipboardImpl::getString()
 
     if (!IsClipboardFormatAvailable(CF_UNICODETEXT))
     {
-        std::cerr << "Failed to get the clipboard data in Unicode format." << std::endl;
+        err() << "Failed to get the clipboard data in Unicode format: " << getErrorString(GetLastError()) << std::endl;
         return text;
     }
 
     if (!OpenClipboard(NULL))
     {
-        std::cerr << "Failed to open the Win32 clipboard." << std::endl;
+        err() << "Failed to open the Win32 clipboard: " << getErrorString(GetLastError()) << std::endl;
         return text;
     }
 
@@ -56,7 +72,7 @@ String ClipboardImpl::getString()
 
     if (!clipboard_handle)
     {
-        std::cerr << "Failed to get Win32 handle for clipboard content." << std::endl;
+        err() << "Failed to get Win32 handle for clipboard content: " << getErrorString(GetLastError()) << std::endl;
         CloseClipboard();
         return text;
     }
@@ -74,13 +90,14 @@ void ClipboardImpl::setString(const String& text)
 {
     if (!OpenClipboard(NULL))
     {
-        std::cerr << "Failed to open the Win32 clipboard." << std::endl;
+        err() << "Failed to open the Win32 clipboard: " << getErrorString(GetLastError()) << std::endl;
         return;
     }
 
     if (!EmptyClipboard())
     {
-        std::cerr << "Failed to empty the Win32 clipboard." << std::endl;
+        err() << "Failed to empty the Win32 clipboard: " << getErrorString(GetLastError()) << std::endl;
+        CloseClipboard();
         return;
     }
 
