@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -36,7 +36,8 @@ namespace priv
 
 ////////////////////////////////////////////////////////////
 CursorImpl::CursorImpl() :
-m_cursor(NULL)
+m_cursor(NULL),
+m_systemCursor(false)
 {
     // That's it.
 }
@@ -59,8 +60,8 @@ bool CursorImpl::loadFromPixels(const Uint8* pixels, Vector2u size, Vector2u hot
     std::memset(&bitmapHeader, 0, sizeof(BITMAPV5HEADER));
 
     bitmapHeader.bV5Size        = sizeof(BITMAPV5HEADER);
-    bitmapHeader.bV5Width       = size.x;
-    bitmapHeader.bV5Height      = -static_cast<int>(size.y); // Negative indicates origin is in upper-left corner
+    bitmapHeader.bV5Width       = static_cast<LONG>(size.x);
+    bitmapHeader.bV5Height      = -static_cast<LONG>(size.y); // Negative indicates origin is in upper-left corner
     bitmapHeader.bV5Planes      = 1;
     bitmapHeader.bV5BitCount    = 32;
     bitmapHeader.bV5Compression = BI_BITFIELDS;
@@ -93,11 +94,11 @@ bool CursorImpl::loadFromPixels(const Uint8* pixels, Vector2u size, Vector2u hot
     Uint32* bitmapOffset = bitmapData;
     for (std::size_t remaining = size.x * size.y; remaining > 0; --remaining, pixels += 4)
     {
-        *bitmapOffset++ = (pixels[3] << 24) | (pixels[0] << 16) | (pixels[1] << 8) | pixels[2];
+        *bitmapOffset++ = static_cast<Uint32>((pixels[3] << 24) | (pixels[0] << 16) | (pixels[1] << 8) | pixels[2]);
     }
 
     // Create a dummy mask bitmap (it won't be used)
-    HBITMAP mask = CreateBitmap(size.x, size.y, 1, 1, NULL);
+    HBITMAP mask = CreateBitmap(static_cast<int>(size.x), static_cast<int>(size.y), 1, 1, NULL);
 
     if (!mask)
     {
@@ -118,6 +119,7 @@ bool CursorImpl::loadFromPixels(const Uint8* pixels, Vector2u size, Vector2u hot
 
     // Create the cursor
     m_cursor = reinterpret_cast<HCURSOR>(CreateIconIndirect(&cursorInfo));
+    m_systemCursor = false;
 
     // The data has been copied into the cursor, so get rid of these
     DeleteObject(color);
@@ -140,7 +142,7 @@ bool CursorImpl::loadFromSystem(Cursor::Type type)
 {
     release();
 
-    LPCTSTR shape;
+    LPCTSTR shape = NULL;
     switch (type)
     {
         case Cursor::Arrow:                  shape = IDC_ARROW;       break;
@@ -152,14 +154,23 @@ bool CursorImpl::loadFromSystem(Cursor::Type type)
         case Cursor::SizeVertical:           shape = IDC_SIZENS;      break;
         case Cursor::SizeTopLeftBottomRight: shape = IDC_SIZENWSE;    break;
         case Cursor::SizeBottomLeftTopRight: shape = IDC_SIZENESW;    break;
+        case Cursor::SizeLeft:               shape = IDC_SIZEWE;      break;
+        case Cursor::SizeRight:              shape = IDC_SIZEWE;      break;
+        case Cursor::SizeTop:                shape = IDC_SIZENS;      break;
+        case Cursor::SizeBottom:             shape = IDC_SIZENS;      break;
+        case Cursor::SizeTopLeft:            shape = IDC_SIZENWSE;    break;
+        case Cursor::SizeBottomRight:        shape = IDC_SIZENWSE;    break;
+        case Cursor::SizeBottomLeft:         shape = IDC_SIZENESW;    break;
+        case Cursor::SizeTopRight:           shape = IDC_SIZENESW;    break;
         case Cursor::SizeAll:                shape = IDC_SIZEALL;     break;
         case Cursor::Cross:                  shape = IDC_CROSS;       break;
         case Cursor::Help:                   shape = IDC_HELP;        break;
         case Cursor::NotAllowed:             shape = IDC_NO;          break;
     }
 
-    // Create a copy of the shared system cursor that we can destroy later
-    m_cursor = CopyCursor(LoadCursor(NULL, shape));
+    // Get the shared system cursor and make sure not to destroy it
+    m_cursor = LoadCursor(NULL, shape);
+    m_systemCursor = true;
 
     if (m_cursor)
     {
@@ -176,7 +187,7 @@ bool CursorImpl::loadFromSystem(Cursor::Type type)
 ////////////////////////////////////////////////////////////
 void CursorImpl::release()
 {
-    if (m_cursor) {
+    if (m_cursor && !m_systemCursor) {
         DestroyCursor(m_cursor);
         m_cursor = NULL;
     }
