@@ -1,7 +1,7 @@
 ////////////////////////////////////////////////////////////
 //
 // SFML - Simple and Fast Multimedia Library
-// Copyright (C) 2007-2018 Laurent Gomila (laurent@sfml-dev.org)
+// Copyright (C) 2007-2023 Laurent Gomila (laurent@sfml-dev.org)
 //
 // This software is provided 'as-is', without any express or implied warranty.
 // In no event will the authors be held liable for any damages arising from the use of this software.
@@ -26,7 +26,6 @@
 // Headers
 ////////////////////////////////////////////////////////////
 #include <SFML/Window/WindowImpl.hpp> // included first to avoid a warning about macro redefinition
-#include <SFML/OpenGL.hpp> // included second to avoid an error in WglExtensions.hpp
 #include <SFML/Window/Win32/WglContext.hpp>
 #include <SFML/System/ThreadLocalPtr.hpp>
 #include <SFML/System/Lock.hpp>
@@ -35,12 +34,50 @@
 #include <sstream>
 #include <vector>
 
+// We check for this definition in order to avoid multiple definitions of GLAD
+// entities during unity builds of SFML.
+#ifndef SF_GLAD_WGL_IMPLEMENTATION_INCLUDED
+#define SF_GLAD_WGL_IMPLEMENTATION_INCLUDED
+#define SF_GLAD_WGL_IMPLEMENTATION
+#include <glad/wgl.h>
+#endif
 
 namespace
 {
-    // Some drivers are bugged and don't track the current HDC/HGLRC properly
-    // In order to deactivate successfully, we need to track it ourselves as well
-    sf::ThreadLocalPtr<sf::priv::WglContext> currentContext(NULL);
+    namespace WglContextImpl
+    {
+        // Some drivers are bugged and don't track the current HDC/HGLRC properly
+        // In order to deactivate successfully, we need to track it ourselves as well
+        sf::ThreadLocalPtr<sf::priv::WglContext> currentContext(NULL);
+
+
+        ////////////////////////////////////////////////////////////
+        void ensureInit()
+        {
+            static bool initialized = false;
+            if (!initialized)
+            {
+                initialized = true;
+
+                gladLoadWGL(NULL, sf::priv::WglContext::getFunction);
+            }
+        }
+
+
+        ////////////////////////////////////////////////////////////
+        void ensureExtensionsInit(HDC deviceContext)
+        {
+            static bool initialized = false;
+            if (!initialized)
+            {
+                initialized = true;
+
+                // We don't check the return value since the extension
+                // flags are cleared even if loading fails
+                gladLoadWGL(deviceContext, sf::priv::WglContext::getFunction);
+            }
+        }
+    }
 }
 
 
@@ -48,31 +85,20 @@ namespace sf
 {
 namespace priv
 {
-////////////////////////////////////////////////////////////
-void ensureExtensionsInit(HDC deviceContext)
-{
-    static bool initialized = false;
-    if (!initialized)
-    {
-        initialized = true;
-
-        // We don't check the return value since the extension
-        // flags are cleared even if loading fails
-        sfwgl_LoadFunctions(deviceContext);
-    }
-}
-
-
 ////////////////////////////////////////////////////////////
 String getErrorString(DWORD errorCode)
 {
-    std::basic_ostringstream<TCHAR, std::char_traits<TCHAR> > ss;
-    TCHAR errBuff[256];
-    FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM, NULL, errorCode, 0, errBuff, sizeof(errBuff), NULL);
-    ss << errBuff;
-    String errMsg(ss.str());
+    PTCHAR buffer;
+    if (FormatMessage(FORMAT_MESSAGE_MAX_WIDTH_MASK | FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, NULL, errorCode, 0, reinterpret_cast<LPTSTR>(&buffer), 256, NULL) != 0)
+    {
+        String errMsg(buffer);
+        LocalFree(buffer);
+        return errMsg;
+    }
 
-    return errMsg;
+    std::ostringstream ss;
+    ss << "Error " << errorCode;
+    return String(ss.str());
 }
 
 
@@ -84,20 +110,18 @@ m_deviceContext(NULL),
 m_context      (NULL),
 m_ownsWindow   (false)
 {
+    WglContextImpl::ensureInit();
+
+    // TODO: Delegate to the other constructor in C++11
+
     // Save the creation settings
     m_settings = ContextSettings();
 
-    // Make sure that extensions are initialized if this is not the shared context
-    // The shared context is the context used to initialize the extensions
-    if (shared && shared->m_deviceContext)
-        ensureExtensionsInit(shared->m_deviceContext);
-
     // Create the rendering surface (window or pbuffer if supported)
     createSurface(shared, 1, 1, VideoMode::getDesktopMode().bitsPerPixel);
 
     // Create the context
-    if (m_deviceContext)
-        createContext(shared);
+    createContext(shared);
 }
 
 
@@ -109,20 +133,16 @@ m_deviceContext(NULL),
 m_context      (NULL),
 m_ownsWindow   (false)
 {
+    WglContextImpl::ensureInit();
+
     // Save the creation settings
     m_settings = settings;
 
-    // Make sure that extensions are initialized if this is not the shared context
-    // The shared context is the context used to initialize the extensions
-    if (shared && shared->m_deviceContext)
-        ensureExtensionsInit(shared->m_deviceContext);
-
     // Create the rendering surface from the owner window
     createSurface(owner->getSystemHandle(), bitsPerPixel);
 
     // Create the context
-    if (m_deviceContext)
-        createContext(shared);
+    createContext(shared);
 }
 
 
@@ -134,20 +154,16 @@ m_deviceContext(NULL),
 m_context      (NULL),
 m_ownsWindow   (false)
 {
+    WglContextImpl::ensureInit();
+
     // Save the creation settings
     m_settings = settings;
 
-    // Make sure that extensions are initialized if this is not the shared context
-    // The shared context is the context used to initialize the extensions
-    if (shared && shared->m_deviceContext)
-        ensureExtensionsInit(shared->m_deviceContext);
-
     // Create the rendering surface (window or pbuffer if supported)
     createSurface(shared, width, height, VideoMode::getDesktopMode().bitsPerPixel);
 
     // Create the context
-    if (m_deviceContext)
-        createContext(shared);
+    createContext(shared);
 }
 
 
@@ -160,10 +176,10 @@ WglContext::~WglContext()
     // Destroy the OpenGL context
     if (m_context)
     {
-        if (currentContext == this)
+        if (WglContextImpl::currentContext == this)
         {
             if (wglMakeCurrent(m_deviceContext, NULL) == TRUE)
-                currentContext = NULL;
+                WglContextImpl::currentContext = NULL;
         }
 
         wglDeleteContext(m_context);
@@ -227,7 +243,7 @@ bool WglContext::makeCurrent(bool current)
         return false;
     }
 
-    currentContext = (current ? this : NULL);
+    WglContextImpl::currentContext = (current ? this : NULL);
 
     return true;
 }
@@ -245,9 +261,9 @@ void WglContext::display()
 void WglContext::setVerticalSyncEnabled(bool enabled)
 {
     // Make sure that extensions are initialized
-    ensureExtensionsInit(m_deviceContext);
+    WglContextImpl::ensureExtensionsInit(m_deviceContext);
 
-    if (sfwgl_ext_EXT_swap_control == sfwgl_LOAD_SUCCEEDED)
+    if (SF_GLAD_WGL_EXT_swap_control)
     {
         if (wglSwapIntervalEXT(enabled ? 1 : 0) == FALSE)
             err() << "Setting vertical sync failed: " << getErrorString(GetLastError()).toAnsiString() << std::endl;
@@ -270,9 +286,11 @@ void WglContext::setVerticalSyncEnabled(bool enabled)
 ////////////////////////////////////////////////////////////
 int WglContext::selectBestPixelFormat(HDC deviceContext, unsigned int bitsPerPixel, const ContextSettings& settings, bool pbuffer)
 {
+    WglContextImpl::ensureInit();
+
     // Let's find a suitable pixel format -- first try with wglChoosePixelFormatARB
     int bestFormat = 0;
-    if (sfwgl_ext_ARB_pixel_format == sfwgl_LOAD_SUCCEEDED)
+    if (SF_GLAD_WGL_ARB_pixel_format)
     {
         // Define the basic attributes we want for our window
         int intAttributes[] =
@@ -286,7 +304,7 @@ int WglContext::selectBestPixelFormat(HDC deviceContext, unsigned int bitsPerPix
 
         // Let's check how many formats are supporting our requirements
         int  formats[512];
-        UINT nbFormats;
+        UINT nbFormats = 0; // We must initialize to 0 otherwise broken drivers might fill with garbage in the following call
         bool isValid = wglChoosePixelFormatARB(deviceContext, intAttributes, NULL, 512, formats, &nbFormats) != FALSE;
 
         if (!isValid)
@@ -318,7 +336,7 @@ int WglContext::selectBestPixelFormat(HDC deviceContext, unsigned int bitsPerPix
                 }
 
                 int sampleValues[2] = {0, 0};
-                if (sfwgl_ext_ARB_multisample == sfwgl_LOAD_SUCCEEDED)
+                if (SF_GLAD_WGL_ARB_multisample)
                 {
                     const int sampleAttributes[] =
                     {
@@ -334,7 +352,7 @@ int WglContext::selectBestPixelFormat(HDC deviceContext, unsigned int bitsPerPix
                 }
 
                 int sRgbCapableValue = 0;
-                if ((sfwgl_ext_ARB_framebuffer_sRGB == sfwgl_LOAD_SUCCEEDED) || (sfwgl_ext_EXT_framebuffer_sRGB == sfwgl_LOAD_SUCCEEDED))
+                if (SF_GLAD_WGL_ARB_framebuffer_sRGB || SF_GLAD_WGL_EXT_framebuffer_sRGB)
                 {
                     const int sRgbCapableAttribute = WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB;
 
@@ -455,15 +473,15 @@ void WglContext::updateSettingsFromPixelFormat()
         return;
     }
 
-    if (sfwgl_ext_ARB_pixel_format == sfwgl_LOAD_SUCCEEDED)
+    if (SF_GLAD_WGL_ARB_pixel_format)
     {
         const int attributes[] = {WGL_DEPTH_BITS_ARB, WGL_STENCIL_BITS_ARB};
         int values[2];
 
         if (wglGetPixelFormatAttribivARB(m_deviceContext, format, PFD_MAIN_PLANE, 2, attributes, values) == TRUE)
         {
-            m_settings.depthBits   = values[0];
-            m_settings.stencilBits = values[1];
+            m_settings.depthBits   = static_cast<unsigned int>(values[0]);
+            m_settings.stencilBits = static_cast<unsigned int>(values[1]);
         }
         else
         {
@@ -472,14 +490,14 @@ void WglContext::updateSettingsFromPixelFormat()
             m_settings.stencilBits = actualFormat.cStencilBits;
         }
 
-        if (sfwgl_ext_ARB_multisample == sfwgl_LOAD_SUCCEEDED)
+        if (SF_GLAD_WGL_ARB_multisample)
         {
             const int sampleAttributes[] = {WGL_SAMPLE_BUFFERS_ARB, WGL_SAMPLES_ARB};
             int sampleValues[2];
 
             if (wglGetPixelFormatAttribivARB(m_deviceContext, format, PFD_MAIN_PLANE, 2, sampleAttributes, sampleValues) == TRUE)
             {
-                m_settings.antialiasingLevel = sampleValues[0] ? sampleValues[1] : 0;
+                m_settings.antialiasingLevel = static_cast<unsigned int>(sampleValues[0] ? sampleValues[1] : 0);
             }
             else
             {
@@ -492,7 +510,7 @@ void WglContext::updateSettingsFromPixelFormat()
             m_settings.antialiasingLevel = 0;
         }
 
-        if ((sfwgl_ext_ARB_framebuffer_sRGB == sfwgl_LOAD_SUCCEEDED) || (sfwgl_ext_EXT_framebuffer_sRGB == sfwgl_LOAD_SUCCEEDED))
+        if (SF_GLAD_WGL_ARB_framebuffer_sRGB || SF_GLAD_WGL_EXT_framebuffer_sRGB)
         {
             const int sRgbCapableAttribute = WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB;
             int sRgbCapableValue = 0;
@@ -525,7 +543,7 @@ void WglContext::updateSettingsFromPixelFormat()
 void WglContext::createSurface(WglContext* shared, unsigned int width, unsigned int height, unsigned int bitsPerPixel)
 {
     // Check if the shared context already exists and pbuffers are supported
-    if (shared && shared->m_deviceContext && (sfwgl_ext_ARB_pbuffer == sfwgl_LOAD_SUCCEEDED))
+    if (shared && shared->m_deviceContext && SF_GLAD_WGL_ARB_pbuffer)
     {
         int bestFormat = selectBestPixelFormat(shared->m_deviceContext, bitsPerPixel, m_settings, true);
 
@@ -533,7 +551,7 @@ void WglContext::createSurface(WglContext* shared, unsigned int width, unsigned
         {
             int attributes[] = {0, 0};
 
-            m_pbuffer = wglCreatePbufferARB(shared->m_deviceContext, bestFormat, width, height, attributes);
+            m_pbuffer = wglCreatePbufferARB(shared->m_deviceContext, bestFormat, static_cast<int>(width), static_cast<int>(height), attributes);
 
             if (m_pbuffer)
             {
@@ -562,7 +580,7 @@ void WglContext::createSurface(WglContext* shared, unsigned int width, unsigned
         // with other contexts and thus wglShareLists would always fail
 
         // Create the hidden window
-        m_window = CreateWindowA("STATIC", "", WS_POPUP | WS_DISABLED, 0, 0, width, height, NULL, NULL, GetModuleHandle(NULL), NULL);
+        m_window = CreateWindowA("STATIC", "", WS_POPUP | WS_DISABLED, 0, 0, static_cast<int>(width), static_cast<int>(height), NULL, NULL, GetModuleHandle(NULL), NULL);
         ShowWindow(m_window, SW_HIDE);
         m_deviceContext = GetDC(m_window);
 
@@ -594,6 +612,10 @@ void WglContext::createSurface(HWND window, unsigned int bitsPerPixel)
 ////////////////////////////////////////////////////////////
 void WglContext::createContext(WglContext* shared)
 {
+    // We can't create an OpenGL context if we don't have a DC
+    if (!m_deviceContext)
+        return;
+
     // Get a working copy of the context settings
     ContextSettings settings = m_settings;
 
@@ -603,7 +625,7 @@ void WglContext::createContext(WglContext* shared)
     // Create the OpenGL context -- first try using wglCreateContextAttribsARB
     while (!m_context && m_settings.majorVersion)
     {
-        if (sfwgl_ext_ARB_create_context == sfwgl_LOAD_SUCCEEDED)
+        if (SF_GLAD_WGL_ARB_create_context)
         {
             std::vector<int> attributes;
 
@@ -611,13 +633,13 @@ void WglContext::createContext(WglContext* shared)
             if ((m_settings.majorVersion > 1) || ((m_settings.majorVersion == 1) && (m_settings.minorVersion > 1)))
             {
                 attributes.push_back(WGL_CONTEXT_MAJOR_VERSION_ARB);
-                attributes.push_back(m_settings.majorVersion);
+                attributes.push_back(static_cast<int>(m_settings.majorVersion));
                 attributes.push_back(WGL_CONTEXT_MINOR_VERSION_ARB);
-                attributes.push_back(m_settings.minorVersion);
+                attributes.push_back(static_cast<int>(m_settings.minorVersion));
             }
 
             // Check if setting the profile is supported
-            if (sfwgl_ext_ARB_create_context_profile == sfwgl_LOAD_SUCCEEDED)
+            if (SF_GLAD_WGL_ARB_create_context_profile)
             {
                 int profile = (m_settings.attributeFlags & ContextSettings::Core) ? WGL_CONTEXT_CORE_PROFILE_BIT_ARB : WGL_CONTEXT_COMPATIBILITY_PROFILE_BIT_ARB;
                 int debug = (m_settings.attributeFlags & ContextSettings::Debug) ? WGL_CONTEXT_DEBUG_BIT_ARB : 0;
@@ -645,7 +667,7 @@ void WglContext::createContext(WglContext* shared)
                 static Mutex mutex;
                 Lock lock(mutex);
 
-                if (currentContext == shared)
+                if (WglContextImpl::currentContext == shared)
                 {
                     if (wglMakeCurrent(shared->m_deviceContext, NULL) == FALSE)
                     {
@@ -653,7 +675,7 @@ void WglContext::createContext(WglContext* shared)
                         return;
                     }
 
-                    currentContext = NULL;
+                    WglContextImpl::currentContext = NULL;
                 }
             }
 
@@ -715,7 +737,7 @@ void WglContext::createContext(WglContext* shared)
             static Mutex mutex;
             Lock lock(mutex);
 
-            if (currentContext == shared)
+            if (WglContextImpl::currentContext == shared)
             {
                 if (wglMakeCurrent(shared->m_deviceContext, NULL) == FALSE)
                 {
@@ -723,13 +745,22 @@ void WglContext::createContext(WglContext* shared)
                     return;
                 }
 
-                currentContext = NULL;
+                WglContextImpl::currentContext = NULL;
             }
 
             if (wglShareLists(sharedContext, m_context) == FALSE)
                 err() << "Failed to share the OpenGL context: " << getErrorString(GetLastError()).toAnsiString() << std::endl;
         }
     }
+
+    // If we are the shared context, initialize extensions now
+    // This enables us to re-create the shared context using extensions if we need to
+    if (!shared && m_context)
+    {
+        makeCurrent(true);
+        WglContextImpl::ensureExtensionsInit(m_deviceContext);
+        makeCurrent(false);
+    }
 }
 
 } // namespace priv
